@@ -22,7 +22,11 @@
 
 from __future__ import print_function
 
-import simplejson as json
+try:
+    import simplejson as json
+except ImportError:
+    import json
+
 import logging
 import os
 import sys
@@ -40,9 +44,9 @@ AppGroup = "Application"
 CocaineGroup = "Cocaine"
 ActionGroup = "Actions"
 
-POSSIBLE_ACTIONS = ('upload', 'deploy', 'start', 'stop', 'restart',
+POSSIBLE_ACTIONS = ('upload', 'deploy', 'start', 'stop', 'restart', 'check',
                     'fastdeploy', 'listing', 'undeploy', 'info', 'remove')
-API_VERSION = 1.3
+API_VERSION = 1.4
 DEFAULT_REQUEST_TIMEOUT = 200
 
 
@@ -66,6 +70,14 @@ def printer(data):
           file=sys.stderr)
 
 
+def json_printer(data):
+    try:
+        print(json.dumps(json.loads(data),
+              sort_keys=True, indent=4 * ' '))
+    except Exception:
+        print(data)
+
+
 def run_request(req):
     req.connect_timeout = 5
     req.request_timeout = options.timeout
@@ -238,6 +250,21 @@ def restart():
     start()
 
 
+@Dispatcher.attach('check')
+@jail
+def check():
+    check_version_and_appname()
+    task = {"appname": options.appname,
+            "environment": options.environment,
+            "version": options.version}
+    task = gen_task(task)
+    req = HTTPRequest(gen_url("check"),
+                      method="POST",
+                      streaming_callback=json_printer,
+                      body=task)
+    run_request(req)
+
+
 @Dispatcher.attach("deploy")
 @jail
 def deploy():
@@ -333,18 +360,11 @@ def listing():
 @Dispatcher.attach("info")
 @jail
 def info():
-    def pretty_print(data):
-        try:
-            print(json.dumps(json.loads(data),
-                  sort_keys=True, indent=4 * ' '))
-        except Exception:
-            print(data)
-
     log.info("Fetching a list of your applications")
     task = gen_task(None)
     req = HTTPRequest(gen_url("info"),
                       method="POST",
-                      streaming_callback=pretty_print,
+                      streaming_callback=json_printer,
                       body=task)
     run_request(req)
 
